#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.apps import AppConfig


class CalAccessRawConfig(AppConfig):
    name = 'calaccess_raw'
    verbose_name = "CAL-ACCESS raw data"
